@@ -18,6 +18,7 @@
 #' can improve convergence. By default, \code{"mean1"} scales the catch so that time series mean is 1, otherwise a numeric.
 #' Output is re-converted back to original units.
 #' @param start Optional list of starting values. Entries can be expressions that are evaluated in the function. See details.
+#' @param prior A named list for the parameters of any priors to be added to the model. See details.
 #' @param fix_dep Logical, whether to fix the initial depletion (ratio of biomass to carrying capacity in the
 #' first year of the model). If \code{TRUE}, uses the value in \code{start}, otherwise equal to 1
 #' (unfished conditions).
@@ -37,10 +38,9 @@
 #' Ignored if \code{n_seas} = 1.
 #' @param integrate Logical, whether the likelihood of the model integrates over the likelihood
 #' of the biomass deviations (thus, treating it as a state-space variable).
-#' @param use_r_prior Logical, whether a prior for the intrinsic rate of increase will be used in the model. See details.
-#' @param r_reps If \code{use_r_prior = TRUE}, the number of samples of natural mortality and steepness for calculating the
-#' mean and standard deviation of the r prior. To override and directly provide the r-prior mean and standard deviation, use the start list, e.g.
-#' \code{start = list(r_prior = c(0.1, 0.05))} (mean of 0.1 and s.d. of 0.05).
+#' @param Euler_Lotka Integer. If greater than zero, the function will calculate a prior for the intrinsic rate of increase to use in the estimation model
+#' (in lieu of an explicit prior in argument \code{prior}). The value of this argument specifies the number of stochastic samples used to calculate the prior SD. 
+#' See section on priors below.
 #' @param SR_type If \code{use_r_prior = TRUE}, the stock-recruit relationship used to calculate the stock-recruit alpha parameter from 
 #' steepness and unfished spawners-per-recruit. Used to develop the r prior.
 #' @param silent Logical, passed to \code{\link[TMB]{MakeADFun}}, whether TMB
@@ -68,12 +68,18 @@
 #' }
 #' 
 #' Multiple indices are supported in the model. 
-#'
-#' If \code{use_r_prior = TRUE}, \code{SP} and \code{SP_SS} will use a prior for the intrinsic rate of increase in the objective function.
-#' A vector of length two can be passed in the \code{start} list for the mean and standard deviation of the prior (see example). The normal
-#' distribution is used.
-#'
-#' If no values are provided, a prior is created using the Euler-Lotka method (Equation 15a of McAllister et al. 2001).
+#' 
+#' Tip: to create the Fox model (Fox 1970), just fix n = 1. See example.
+#' @section Priors:
+#' The following priors can be added as a named list, e.g., prior = list(r = c(0.25, 0.15), MSY = c(50, 0.1). For each parameter below, provide a vector of values as described:
+#' 
+#' \itemize{
+#' \item \code{r} - A vector of length 2 for the lognormal prior mean (normal space) and SD (lognormal space). 
+#' \item \code{MSY} - A vector of length 2 for the lognormal prior mean (normal space) and SD (lognormal space).
+#' }
+#' 
+#' In lieu of an explicit r prior provided by the user, set argument \code{Euler_Lotka = TRUE} to calculate the prior mean and SD using
+#' the Euler-Lotka method (Equation 15a of McAllister et al. 2001).
 #' The Euler-Lotka method is modified to multiply the left-hand side of equation 15a by the alpha parameter of the
 #' stock-recruit relationship (Stanley et al. 2009). Natural mortality and steepness are sampled in order to generate
 #' a prior distribution for r. See \code{vignette("Surplus_production")} for more details.
@@ -81,8 +87,6 @@
 #' @note The model uses the Fletcher (1978) formulation and is parameterized with FMSY and MSY as
 #' leading parameters. The default conditions assume unfished conditions in the first year of the time series
 #' and a symmetric production function (n = 2).
-#'
-#' Tip: to create the Fox model (Fox 1970), just fix n = 1. See example.
 #' 
 #' @section Online Documentation:
 #' Model description and equations are available on the openMSE 
@@ -141,19 +145,25 @@
 #' res_Fox <- SP(Data = swordfish, start = list(n = 1), fix_n = TRUE)
 #' res_Fox2 <- SP_Fox(Data = swordfish)
 #'
-#' #### SP with r_prior
-#' res_prior <- SP(Data = SimulatedData, use_r_prior = TRUE)
+#' #### SP with r prior calculated internally (100 stochastic samples to get prior SD)
+#' res_prior <- SP(Data = SimulatedData, Euler_Lotka = 100)
 #'
-#' #### Pass an r_prior to the model with mean = 0.35, sd = 0.10
-#' res_prior2 <- SP(Data = SimulatedData, use_r_prior = TRUE, start = list(r_prior = c(0.35, 0.10)))
+#' #### Pass an r prior to the model with mean = 0.35, lognormal sd = 0.10
+#' res_prior2 <- SP(Data = SimulatedData, prior = list(r = c(0.35, 0.10)))
+#' 
+#' #### Pass MSY prior to the model with mean = 1500, lognormal sd = 0.05
+#' res_prior3 <- SP(Data = SimulatedData, prior = list(MSY = c(1500, 0.05)))
 #' @seealso \link{SP_production} \link{plot.Assessment} \link{summary.Assessment} \link{retrospective} \link{profile} \link{make_MP}
 #' @export
-SP <- function(x = 1, Data, AddInd = "B", rescale = "mean1", start = NULL, fix_dep = TRUE, fix_n = TRUE, LWT = NULL,
-               n_seas = 4L, n_itF = 3L, use_r_prior = FALSE, r_reps = 1e2, SR_type = c("BH", "Ricker"),
+SP <- function(x = 1, Data, AddInd = "B", rescale = "mean1", start = NULL, prior = list(),
+               fix_dep = TRUE, fix_n = TRUE, LWT = NULL,
+               n_seas = 4L, n_itF = 3L, Euler_Lotka = 0L, SR_type = c("BH", "Ricker"),
                silent = TRUE, opt_hess = FALSE, n_restart = ifelse(opt_hess, 0, 1),
                control = list(iter.max = 5e3, eval.max = 1e4), ...) {
-  SP_(x = x, Data = Data, AddInd = AddInd, state_space = FALSE, rescale = rescale, start = start, fix_dep = fix_dep, fix_n = fix_n, fix_sigma = TRUE,
-      fix_tau = TRUE, LWT = LWT, n_seas = n_seas, n_itF = n_itF, use_r_prior = use_r_prior, r_reps = r_reps, SR_type = SR_type, integrate = FALSE,
+  SP_(x = x, Data = Data, AddInd = AddInd, state_space = FALSE, rescale = rescale, start = start, prior = prior, 
+      fix_dep = fix_dep, fix_n = fix_n, fix_sigma = TRUE,
+      fix_tau = TRUE, LWT = LWT, n_seas = n_seas, n_itF = n_itF, 
+      Euler_Lotka = Euler_Lotka, SR_type = SR_type, integrate = FALSE,
       silent = silent, opt_hess = opt_hess, n_restart = n_restart, control = control, inner.control = list(), ...)
 }
 class(SP) <- "Assess"
@@ -161,13 +171,16 @@ class(SP) <- "Assess"
 
 #' @rdname SP
 #' @export
-SP_SS <- function(x = 1, Data, AddInd = "B", rescale = "mean1", start = NULL, fix_dep = TRUE, fix_n = TRUE, fix_sigma = TRUE,
+SP_SS <- function(x = 1, Data, AddInd = "B", rescale = "mean1", start = NULL, prior = list(), 
+                  fix_dep = TRUE, fix_n = TRUE, fix_sigma = TRUE,
                   fix_tau = TRUE, LWT = NULL, early_dev = c("all", "index"), n_seas = 4L, n_itF = 3L,
-                  use_r_prior = FALSE, r_reps = 1e2, SR_type = c("BH", "Ricker"), integrate = FALSE,
+                  Euler_Lotka = 0L, SR_type = c("BH", "Ricker"), integrate = FALSE,
                   silent = TRUE, opt_hess = FALSE, n_restart = ifelse(opt_hess, 0, 1),
                   control = list(iter.max = 5e3, eval.max = 1e4), inner.control = list(), ...) {
-  SP_(x = x, Data = Data, AddInd = AddInd, state_space = TRUE, rescale = rescale, start = start, fix_dep = fix_dep, fix_n = fix_n, fix_sigma = fix_sigma,
-      fix_tau = fix_tau, early_dev = early_dev, LWT = LWT, n_seas = n_seas, n_itF = n_itF, use_r_prior = use_r_prior, r_reps = r_reps,
+  SP_(x = x, Data = Data, AddInd = AddInd, state_space = TRUE, rescale = rescale, start = start, prior = prior,
+      fix_dep = fix_dep, fix_n = fix_n, fix_sigma = fix_sigma,
+      fix_tau = fix_tau, early_dev = early_dev, LWT = LWT, n_seas = n_seas, n_itF = n_itF, 
+      Euler_Lotka = Euler_Lotka,
       SR_type = SR_type, integrate = integrate, silent = silent, opt_hess = opt_hess, n_restart = n_restart,
       control = control, inner.control = inner.control, ...)
 }
@@ -180,24 +193,30 @@ SP_Fox <- function(x = 1, Data, ...) {
   SP_args$start$n <- 1
   SP_args$fix_n <- TRUE
   
-  do.call2(SP, SP_args)
+  do.call2("SP", SP_args)
 }
 class(SP_Fox) <- "Assess"
 
 
 #' @useDynLib SAMtool
-SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1", start = NULL, fix_dep = TRUE, fix_n = TRUE, fix_sigma = TRUE,
+SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1", start = NULL, prior = list(),
+                fix_dep = TRUE, fix_n = TRUE, fix_sigma = TRUE,
                 fix_tau = TRUE, early_dev = c("all", "index"), LWT = NULL, n_seas = 4L, n_itF = 3L,
-                use_r_prior = FALSE, r_reps = 1e2, SR_type = c("BH", "Ricker"), integrate = FALSE,
+                Euler_Lotka = 0L, SR_type = c("BH", "Ricker"), integrate = FALSE,
                 silent = TRUE, opt_hess = FALSE, n_restart = ifelse(opt_hess, 0, 1),
                 control = list(iter.max = 5e3, eval.max = 1e4), inner.control = list(), ...) {
 
   dependencies = "Data@Cat, Data@Ind"
   dots <- list(...)
   start <- lapply(start, eval, envir = environment())
+  
+  if (all(c("use_r_prior", "r_reps") %in% names(dots))) { # Backward compatibility
+    if (dots$use_r_prior) Euler_Lotka <- dots$r_reps
+    if ("r_prior" %in% names(start)) prior$r <- start$r_prior
+  }
 
   early_dev <- match.arg(early_dev)
-  if(any(names(dots) == "yind")) {
+  if (any(names(dots) == "yind")) {
     yind <- eval(dots$yind)
   } else {
     ystart <- which(!is.na(Data@Cat[x, ]))[1]
@@ -205,85 +224,82 @@ SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1
   }
   Year <- Data@Year[yind]
   C_hist <- Data@Cat[x, yind]
-  if(any(is.na(C_hist))) stop('Model is conditioned on complete catch time series, but there is missing catch.')
+  if (any(is.na(C_hist))) stop('Model is conditioned on complete catch time series, but there is missing catch.')
   ny <- length(C_hist)
-  if(rescale == "mean1") rescale <- 1/mean(C_hist)
+  if (rescale == "mean1") rescale <- 1/mean(C_hist)
 
   Ind <- lapply(AddInd, Assess_I_hist, Data = Data, x = x, yind = yind)
   I_hist <- vapply(Ind, getElement, numeric(ny), "I_hist")
-  if(is.null(I_hist) || all(is.na(I_hist))) stop("No indices found.", call. = FALSE)
+  if (is.null(I_hist) || all(is.na(I_hist))) stop("No indices found.", call. = FALSE)
   
   I_sd <- vapply(Ind, getElement, numeric(ny), "I_sd")
   nsurvey <- ncol(I_hist)
 
-  if(state_space) {
-    if(early_dev == "all") est_B_dev <- rep(1, ny)
-    if(early_dev == "index") {
+  if (state_space) {
+    if (early_dev == "all") est_B_dev <- rep(1, ny)
+    if (early_dev == "index") {
       first_year_index <- which(apply(I_hist, 1, function(x) any(!is.na(x))))[1]
       est_B_dev <- ifelse(1:ny < first_year_index, 0, 1)
     }
   } else {
-    if(nsurvey == 1 && (AddInd == 0 | AddInd == "B")) {
+    if (nsurvey == 1 && all(AddInd == 0 | AddInd == "B")) {
       fix_sigma <- FALSE # Override: estimate sigma if there's a single survey
     }
     est_B_dev <- rep(0, ny)
   }
-
-  if(is.null(LWT)) LWT <- rep(1, nsurvey)
-  if(length(LWT) != nsurvey) stop("LWT needs to be a vector of length ", nsurvey)
+  
+  if (is.null(prior$r) && Euler_Lotka > 0L) {
+    r_samps <- r_prior_fn(x, Data, r_reps = Euler_Lotka, SR_type = SR_type)
+    prior$r <- c(mean(r_samps), sd(log(r_samps)))
+  }
+  prior <- make_prior_SP(prior)
+  
+  if (is.null(LWT)) LWT <- rep(1, nsurvey)
+  if (length(LWT) != nsurvey) stop("LWT needs to be a vector of length ", nsurvey)
   data <- list(model = "SP", C_hist = C_hist, rescale = rescale, I_hist = I_hist, I_sd = I_sd, I_lambda = LWT,
                fix_sigma = as.integer(fix_sigma), nsurvey = nsurvey, ny = ny,
-               est_B_dev = est_B_dev, nstep = n_seas, dt = 1/n_seas, n_itF = n_itF)
-
-  if(use_r_prior) {
-    if(!is.null(start$r_prior) && length(start$r_prior) == 2) {
-      rp <- data$r_prior <- start$r_prior
-    } else {
-      rp <- r_prior_fn(x, Data, r_reps = r_reps, SR_type = SR_type)
-      data$r_prior <- c(mean(rp), max(sd(rp), 0.1 * mean(rp)))
-    }
-  } else {
-    rp <- data$r_prior <- c(0, 0)
-  }
-
+               est_B_dev = est_B_dev, nstep = n_seas, dt = 1/n_seas, n_itF = n_itF,
+               use_prior = prior$use_prior, prior_dist = prior$pr_matrix,
+               sim_process_error = 0L)
+  
   params <- list()
-  if(!is.null(start)) {
-    if(!is.null(start$FMSY) && is.numeric(start$FMSY)) params$log_FMSY <- log(start$FMSY[1])
-    if(!is.null(start$MSY) && is.numeric(start$MSY)) params$MSYx <- log(start$MSY[1])
-    if(!is.null(start$dep) && is.numeric(start$dep)) params$log_dep <- log(start$dep[1])
-    if(!is.null(start$n) && is.numeric(start$n)) params$log_n <- log(start$n[1])
-    if(!is.null(start$sigma) && is.numeric(start$sigma)) params$log_sigma <- log(start$sigma)
-    if(!is.null(start$tau) && is.numeric(start$tau)) params$log_tau <- log(start$tau[1])
+  if (!is.null(start)) {
+    if (!is.null(start$FMSY) && is.numeric(start$FMSY)) params$log_FMSY <- log(start$FMSY[1])
+    if (!is.null(start$MSY) && is.numeric(start$MSY)) params$MSYx <- log(start$MSY[1])
+    if (!is.null(start$dep) && is.numeric(start$dep)) params$log_dep <- log(start$dep[1])
+    if (!is.null(start$n) && is.numeric(start$n)) params$log_n <- log(start$n[1])
+    if (!is.null(start$sigma) && is.numeric(start$sigma)) params$log_sigma <- log(start$sigma)
+    if (!is.null(start$tau) && is.numeric(start$tau)) params$log_tau <- log(start$tau[1])
   }
-  if(is.null(params$log_FMSY)) params$log_FMSY <- ifelse(is.na(Data@Mort[x]), 0.2, 0.5 * Data@Mort[x]) %>% log()
-  if(is.null(params$MSYx)) params$MSYx <- mean(3 * C_hist * rescale) %>% log()
-  if(is.null(params$log_dep)) params$log_dep <- log(1)
-  if(is.null(params$log_n)) params$log_n <- log(2)
-  if(is.null(params$log_sigma)) params$log_sigma <- rep(log(0.05), nsurvey)
-  if(is.null(params$log_tau)) params$log_tau <- log(0.1)
+  if (is.null(params$log_FMSY)) params$log_FMSY <- ifelse(is.na(Data@Mort[x]), 0.2, 0.5 * Data@Mort[x]) %>% log()
+  if (is.null(params$MSYx)) params$MSYx <- mean(3 * C_hist * rescale) %>% log()
+  if (is.null(params$log_dep)) params$log_dep <- log(1)
+  if (is.null(params$log_n)) params$log_n <- log(2)
+  if (is.null(params$log_sigma)) params$log_sigma <- rep(log(0.05), nsurvey)
+  if (is.null(params$log_tau)) params$log_tau <- log(0.1)
   params$log_B_dev <- rep(0, ny)
 
   map <- list()
-  if(fix_dep) map$log_dep <- factor(NA)
-  if(fix_n) map$log_n <- factor(NA)
-  if(fix_sigma) map$log_sigma <- factor(rep(NA, nsurvey))
-  if(fix_tau) map$log_tau <- factor(NA)
-  if(any(!est_B_dev)) map$log_B_dev <- factor(ifelse(est_B_dev, 1:sum(est_B_dev), NA))
+  if (fix_dep) map$log_dep <- factor(NA)
+  if (fix_n) map$log_n <- factor(NA)
+  if (fix_sigma) map$log_sigma <- factor(rep(NA, nsurvey))
+  if (fix_tau) map$log_tau <- factor(NA)
+  if (any(!est_B_dev)) map$log_B_dev <- factor(ifelse(est_B_dev, 1:sum(est_B_dev), NA))
 
   random <- NULL
-  if(integrate) random <- "log_B_dev"
+  if (integrate) random <- "log_B_dev"
 
-  info <- list(Year = Year, data = data, params = params, rp = rp, control = control, inner.control = inner.control)
+  info <- list(Year = Year, data = data, params = params, control = control, inner.control = inner.control)
 
   obj <- MakeADFun(data = info$data, parameters = info$params, hessian = TRUE,
                    map = map, random = random, DLL = "SAMtool", silent = silent)
   
   high_F <- try(obj$report(c(obj$par, obj$env$last.par[obj$env$random]))$penalty > 0 ||
                   any(is.na(obj$report(c(obj$par, obj$env$last.par[obj$env$random]))$F)), silent = TRUE)
-  if(!is.character(high_F) && !is.na(high_F) && high_F) {
+  if (!is.character(high_F) && !is.na(high_F) && high_F) {
     for(ii in 1:10) {
       obj$par["MSYx"] <- 0.5 + obj$par["MSYx"]
-      if(all(!is.na(obj$report(obj$par)$F)) && 
+      if (all(!is.na(obj$report(obj$par)$F)) && 
          obj$report(c(obj$par, obj$env$last.par[obj$env$random]))$penalty == 0) break
     }
   }
@@ -297,12 +313,14 @@ SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1
 
   nll_report <- ifelse(is.character(opt), ifelse(integrate, NA, report$nll), opt$objective)
   
-  report$dynamic_SSB0 <- SP_dynamic_SSB0(obj, data = info$data, params = info$params, map = map) %>% 
+  report$dynamic_SSB0 <- SP_dynamic_SSB0(obj) %>% 
     structure(names = Yearplusone)
   Assessment <- new("Assessment", Model = ifelse(state_space, "SP_SS", "SP"), 
                     Name = Data@Name, conv = SD$pdHess,
-                    FMSY = report$FMSY, MSY = report$MSY, BMSY = report$BMSY, VBMSY = report$BMSY,
-                    B0 = report$K, VB0 = report$K, FMort = structure(report$F, names = Year),
+                    FMSY = report$FMSY, MSY = report$MSY, 
+                    BMSY = report$BMSY, VBMSY = report$BMSY, SSBMSY = report$BMSY,
+                    B0 = report$K, VB0 = report$K, SSB0 = report$K, 
+                    FMort = structure(report$F, names = Year),
                     F_FMSY = structure(report$F/report$FMSY, names = Year),
                     B = structure(report$B, names = Yearplusone),
                     B_BMSY = structure(report$B/report$BMSY, names = Yearplusone),
@@ -313,14 +331,16 @@ SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1
                     SSB = structure(report$B, names = Yearplusone),
                     SSB_SSBMSY = structure(report$B/report$BMSY, names = Yearplusone),
                     SSB_SSB0 = structure(report$B/report$K, names = Yearplusone),
-                    Obs_Catch = structure(C_hist, names = Year), Obs_Index = structure(I_hist, dimnames = list(Year, paste0("Index_", 1:nsurvey))),
-                    Catch = structure(report$Cpred, names = Year), Index = structure(report$Ipred, dimnames = list(Year, paste0("Index_", 1:nsurvey))),
+                    Obs_Catch = structure(C_hist, names = Year), 
+                    Obs_Index = structure(I_hist, dimnames = list(Year, paste0("Index_", 1:nsurvey))),
+                    Catch = structure(report$Cpred, names = Year), 
+                    Index = structure(report$Ipred, dimnames = list(Year, paste0("Index_", 1:nsurvey))),
                     NLL = structure(c(nll_report, report$nll_comp, report$penalty, report$prior),
                                     names = c("Total", paste0("Index_", 1:nsurvey), "Dev", "Penalty", "Prior")),
                     info = info, obj = obj, opt = opt, SD = SD, TMB_report = report,
                     dependencies = dependencies)
 
-  if(state_space) {
+  if (state_space) {
     Assessment@Dev <- structure(report$log_B_dev, names = Year)
     Assessment@Dev_type <- "log-Biomass deviations"
     Assessment@NLL <- structure(c(nll_report, report$nll_comp, report$penalty, report$prior),
@@ -330,8 +350,8 @@ SP_ <- function(x = 1, Data, AddInd = "B", state_space = FALSE, rescale = "mean1
                                 names = c("Total", paste0("Index_", 1:nsurvey), "Penalty", "Prior"))
   }
 
-  if(Assessment@conv) {
-    if(state_space) {
+  if (Assessment@conv) {
+    if (state_space) {
       SE_Dev <- as.list(SD, "Std. Error")$log_B_dev
       Assessment@SE_Dev <- structure(ifelse(is.na(SE_Dev), 0, SE_Dev), names = Year)
     }
@@ -395,10 +415,13 @@ Euler_Lotka_fn <- function(log_r, M, h, weight, mat, maxage, SR_type) {
 
 SP_dynamic_SSB0 <- function(obj, par = obj$env$last.par.best, ...) {
   dots <- list(...)
-  dots$data$C_hist <- rep(1e-8, dots$data$ny)
-  dots$params$log_dep <- log(1)
+  newdata <- obj$env$data
+  newdata$C_hist <- rep(1e-8, newdata$ny)
   
-  obj2 <- MakeADFun(data = dots$data, parameters = dots$params, map = dots$map, 
+  newparams <- clean_tmb_parameters(obj)
+  newparams$log_dep <- log(1)
+  
+  obj2 <- MakeADFun(data = newdata, parameters = newparams, map = obj$env$map, 
                     random = obj$env$random, DLL = "SAMtool", silent = TRUE)
   obj2$report(par)$B
 }
