@@ -32,12 +32,14 @@
 #' Not used when data are provided in a \linkS4class{RCMdata} object.
 #' @param prior A named list for the parameters of any priors to be added to the model. See below.
 #' @param max_F The maximum F for any fleet in the scoping model (higher F's in the model are penalized in the objective function). See also \code{drop_highF}.
-#' @param cores Integer for the number of CPU cores for the stock reduction analysis.
+#' @param cores Integer for the number of CPU cores (set greater than 1 for parallel processing).
 #' @param integrate Logical, whether to treat recruitment deviations as penalized parameters in the likelihood (FALSE) or random effects to be marginalized out of the likelihood (TRUE).
 #' @param mean_fit Logical, whether to run an additional with mean values of life history parameters from the OM.
 #' @param drop_nonconv Logical, whether to drop non-converged fits of the RCM, including fits where F = NA.
 #' @param drop_highF Logical, whether to drop fits of the RCM where F = \code{max_F}.
 #' @param control A named list of arguments (e.g, max. iterations, etc.) for optimization, to be passed to the control argument of \code{\link[stats]{nlminb}}.
+#' @param start A list of starting values for the TMB model. See details.
+#' @param map A list of \code{map} argument to TMB models to override defaults. See \link[TMB]{MakeADFun} and details.
 #' @param ... Other arguments to pass in for starting values of parameters and fixing parameters. See details.
 #'
 #' @section Priors:
@@ -145,11 +147,19 @@
 #' a-th row to observed age. Thus, all rows should sum to 1. Default is an identity matrix (no ageing error).
 #' \item sel_block - Optional, for time-varying fleet selectivity (in time blocks), a integer matrix of nyears rows and nfleet columns to assigns a selectivity function to a fleet for certain years.
 #' }
-#' 
+#'  
 #' @section Additional arguments:
 #' For \code{RCM}, additional arguments can be passed to the model via \code{...}:
 #'
 #' \itemize{
+#' \item plusgroup: Logical for whether the maximum age is a plusgroup or not. By default, TRUE.
+#' \item fix_dome: Logical for whether the dome selectivity parameter for fleets is fixed. Used primarily for backwards compatibility, this is overridden by map_vul_par.
+#' \item resample: Logical, whether the OM conditioning parameters (recruitment, fishing mortality, SSB, selectivity, etc.) are obtained by sampling the Hessian matrix from
+#' a single model fit. By default FALSE. This feature requires identical biological parameters among simulations.
+#' }
+#' @section start and map:
+#' Starting values can be specified in a named list for the following:
+#' \itemize{
 #' \item vul_par: A matrix of 3 rows and nfleet columns for starting values for fleet selectivity. The three rows correspond
 #' to LFS (length of full selectivity), L5 (length of 5 percent selectivity), and Vmaxlen (selectivity at length Linf). By default,
 #' the starting values are values from the OM object. If any selectivity = "free", then this matrix needs to be of maxage+1 rows where
@@ -160,21 +170,22 @@
 #' the row specifies the selectivity at age. 
 #' \item log_rec_dev: A numeric vector of length nyears for the starting values of the log-recruitment deviations.
 #' \item log_early_rec_dev: A numeric vector of length OM@@maxage for the starting values of the recruitment deviations controlling the abundance-at-age in the first year of the model.
-#' \item map_vul_par: An integer matrix of the same dimension as vul_par. This is the 'map' argument for vul_par in TMB, see \link[TMB]{MakeADFun}, which indicates whether selectivity parameters are fixed
-#' or estimated. If an entry is \code{NA}, the corresponding parameter is fixed in the model to the starting
-#' value. Otherwise, an integer for each independent parameter. By default, selectivity is fixed if there are no age or length composition for that fleet
-#' or survey, otherwise estimated. Unused cells in the vul_par matrix should be given NA in the map matrix.
-#' \item map_ivul_par: The map argument for the survey selectivity parameters (same dimension as ivul_par). Placeholder parameters should have a map value of NA.
-#' \item map_log_early_rec_dev: A vector of length OM@@maxage that indexes which recruitment deviates for the cohorts in the first year of the model are fixed (using NA) or estimated (a separate integer).
-#' By default, no deviates are estimated (all are NA).
-#' \item map_log_rec_dev: A vector of length OM@@nyears that indexes which recruitment deviates are fixed (using NA) or estimated (a separate integer).
-#' By default, all deviates are estimated.
-#' \item plusgroup: Logical for whether the maximum age is a plusgroup or not. By default, TRUE.
-#' \item fix_dome: Logical for whether the dome selectivity parameter for fleets is fixed. Used primarily for backwards compatibility, this is overridden by map_vul_par.
-#' \item resample: Logical, whether the OM conditioning parameters (recruitment, fishing mortality, SSB, selectivity, etc.) are obtained by sampling the Hessian matrix from
-#' a single model fit. By default FALSE. This feature requires identical biological parameters among simulations.
 #' }
-#'
+#' 
+#' Parameters can be fixed with the map argument (also a named list, corresponding to the start list). Each
+#' vector or matrix in the map argument will be the same dimension as in the start entry. If an entry is \code{NA}, the corresponding parameter is fixed in the model to the starting
+#' value. Otherwise, an integer for each independent parameter, i.e., shared or mirrored parameters get the same integer entry.
+#' 
+#' \itemize{
+#' \item vul_par: An integer matrix of the same dimension as vul_par. By default, selectivity is fixed if there are no age or length composition for that fleet
+#' or survey, otherwise estimated. Unused cells in the vul_par matrix should be given NA in the map matrix.
+#' \item ivul_par: The map argument for the survey selectivity parameters (same dimension as ivul_par). Placeholder parameters should have a map value of NA.
+#' \item log_early_rec_dev: A vector of length OM@@maxage that indexes which recruitment deviates for the cohorts in the first year of the model are fixed (using NA) or estimated (a separate integer).
+#' By default, no deviates are estimated (all are NA).
+#' \item log_rec_dev: A vector of length OM@@nyears that indexes which recruitment deviates are fixed (using NA) or estimated (a separate integer).
+#' By default, all these deviates are estimated.
+#' }
+#' 
 #' @section Likelihood weights:
 #' \code{LWT} is an optional named list containing the likelihood weights (values >= 0) with the possible options:
 #' \itemize{
@@ -199,9 +210,9 @@
 #' out <- RCM(OM = pcod$OM, data = pcod$data, 
 #'            condition = "catch", mean_fit = TRUE,
 #'            selectivity = "free", s_selectivity = rep("SSB", ncol(pcod$data@Index)),
-#'            vul_par = matrix(mat_ogive, length(mat_ogive), 1),
-#'            map_vul_par = matrix(NA, length(mat_ogive), 1),
-#'            map_log_early_rec_dev = rep(1, pcod$OM@maxage),
+#'            start = list(vul_par = matrix(mat_ogive, length(mat_ogive), 1)),
+#'            map = list(vul_par = matrix(NA, length(mat_ogive), 1),
+#'                       log_early_rec_dev = rep(1, pcod$OM@maxage)),
 #'            prior = pcod$prior)
 #' plot(out, s_name = colnames(pcod$data@Index))
 #' 
@@ -212,9 +223,9 @@
 #'   RCM(OM = pcod$OM, data = pcod$data, 
 #'       condition = "catch", mean_fit = TRUE,
 #'       selectivity = "free", s_selectivity = rep("SSB", ncol(pcod$data@Index)),
-#'       vul_par = matrix(mat_ogive_age3, length(mat_ogive_age3), 1),
-#'       map_vul_par = matrix(NA, length(mat_ogive_age3), 1),
-#'       map_log_early_rec_dev = rep(1, pcod$OM@maxage),
+#'       start = list(vul_par = matrix(mat_ogive_age3, length(mat_ogive_age3), 1)),
+#'       map = list(vul_par = matrix(NA, length(mat_ogive_age3), 1),   
+#'                  log_early_rec_dev = rep(1, pcod$OM@maxage)),
 #'       prior = pcod$prior)
 #' })
 #'   
@@ -226,7 +237,7 @@
 #' 
 #' @seealso \link{plot.RCModel} \linkS4class{RCModel} \link{compare_RCM} \link{pcod} \link{RCM2MOM} \link{posterior}
 #' @references 
-#' Thorson et al. 2017. Model-based estimates of effective sample size in stock assessmentmodels using the Dirichlet-multinomial distribution.
+#' Thorson et al. 2017. Model-based estimates of effective sample size in stock assessment models using the Dirichlet-multinomial distribution.
 #' Fish. Res. 192:84-93. \doi{10.1016/j.fishres.2016.06.005}
 #' @importFrom dplyr %>%
 #' @export
@@ -238,10 +249,11 @@ setMethod("RCM", signature(OM = "OM", data = "RCMdata"),
           function(OM, data, condition = c("catch", "catch2", "effort"), selectivity = "logistic", s_selectivity = NULL, LWT = list(),
                    comp_like = c("multinomial", "lognormal", "mvlogistic", "dirmult1", "dirmult2"), prior = list(),
                    max_F = 3, cores = 1L, integrate = FALSE, mean_fit = FALSE, drop_nonconv = FALSE,
-                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05), ...) {
+                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05), 
+                   start = list(), map = list(), ...) {
             RCM_int(OM = OM, RCMdata = data, condition = condition, selectivity = selectivity, s_selectivity = s_selectivity, LWT = LWT,
                     comp_like = comp_like, prior = prior, max_F = max_F, cores = cores, integrate = integrate, mean_fit = mean_fit,
-                    drop_nonconv = drop_nonconv, drop_highF = drop_highF, control = control, ...)
+                    drop_nonconv = drop_nonconv, drop_highF = drop_highF, control = control, start = start, map = map, ...)
           })
 
 #' @rdname RCM
@@ -250,75 +262,76 @@ setMethod("RCM", signature(OM = "OM", data = "list"),
           function(OM, data, condition = c("catch", "catch2", "effort"), selectivity = "logistic", s_selectivity = NULL, LWT = list(),
                    comp_like = c("multinomial", "lognormal", "mvlogistic", "dirmult1", "dirmult2"), ESS = c(30, 30), prior = list(),
                    max_F = 3, cores = 1L, integrate = FALSE, mean_fit = FALSE, drop_nonconv = FALSE,
-                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05), ...) {
+                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05),
+                   start = list(), map = list(), ...) {
             
             .Deprecated(msg = "Using a list of input data to RCM is now deprecated. Use an RCMdata object, i.e., new(\"RCMdata\")")
             
             dataS4 <- new("RCMdata")
-            if(length(ESS) == 1) ESS <- rep(ESS, 2)
+            if (length(ESS) == 1) ESS <- rep(ESS, 2)
             
-            if(!is.null(data$Chist)) dataS4@Chist <- data$Chist 
-            if(!is.null(data$C_sd)) dataS4@C_sd <- data$C_sd 
-            if(!is.null(data$Ehist)) dataS4@Ehist <- data$Ehist
+            if (!is.null(data$Chist)) dataS4@Chist <- data$Chist 
+            if (!is.null(data$C_sd)) dataS4@C_sd <- data$C_sd 
+            if (!is.null(data$Ehist)) dataS4@Ehist <- data$Ehist
             
-            if(!is.null(data$CAA)) {
+            if (!is.null(data$CAA)) {
               dataS4@CAA <- data$CAA
-              if(is.matrix(dataS4@CAA)) {
+              if (is.matrix(dataS4@CAA)) {
                 dataS4@CAA_ESS <- apply(dataS4@CAA, 1, sum, na.rm = TRUE) %>% pmin(ESS[1])
               } else {
                 dataS4@CAA_ESS <- apply(dataS4@CAA, c(1, 3), sum, na.rm = TRUE) %>% pmin(ESS[1])
               }
             }
-            if(!is.null(data$CAL)) {
+            if (!is.null(data$CAL)) {
               dataS4@CAL <- data$CAL 
-              if(is.matrix(dataS4@CAL)) {
+              if (is.matrix(dataS4@CAL)) {
                 dataS4@CAL_ESS <- apply(dataS4@CAL, 1, sum, na.rm = TRUE) %>% pmin(ESS[2])
               } else {
                 dataS4@CAL_ESS <- apply(dataS4@CAL, c(1, 3), sum, na.rm = TRUE) %>% pmin(ESS[2])
               }
             }
             
-            if(!is.null(data$length_bin)) dataS4@length_bin <- data$length_bin 
-            if(!is.null(data$MS)) dataS4@MS <- data$MS
-            if(!is.null(data$MS_type)) dataS4@MS_type <- data$MS_type
-            if(!is.null(data$MS_cv)) dataS4@MS_cv <- data$MS_cv
+            if (!is.null(data$length_bin)) dataS4@length_bin <- data$length_bin 
+            if (!is.null(data$MS)) dataS4@MS <- data$MS
+            if (!is.null(data$MS_type)) dataS4@MS_type <- data$MS_type
+            if (!is.null(data$MS_cv)) dataS4@MS_cv <- data$MS_cv
             
-            if(!is.null(data$Index)) dataS4@Index <- data$Index
-            if(!is.null(data$I_sd)) dataS4@I_sd <- data$I_sd
+            if (!is.null(data$Index)) dataS4@Index <- data$Index
+            if (!is.null(data$I_sd)) dataS4@I_sd <- data$I_sd
             
-            if(!is.null(data$s_CAA)) dataS4@IAA <- data$s_CAA
-            if(!is.null(data$IAA)) dataS4@IAA <- data$IAA
-            if(length(dataS4@IAA)) {
-              if(is.matrix(dataS4@IAA)) {
+            if (!is.null(data$s_CAA)) dataS4@IAA <- data$s_CAA
+            if (!is.null(data$IAA)) dataS4@IAA <- data$IAA
+            if (length(dataS4@IAA)) {
+              if (is.matrix(dataS4@IAA)) {
                 dataS4@IAA_ESS <- apply(dataS4@IAA, 1, sum, na.rm = TRUE) %>% pmin(ESS[1])
               } else {
                 dataS4@IAA_ESS <- apply(dataS4@IAA, c(1, 3), sum, na.rm = TRUE) %>% pmin(ESS[1])
               }
             }
             
-            if(!is.null(data$s_CAL)) dataS4@IAL <- data$s_CAL
-            if(!is.null(data$IAL)) dataS4@IAL <- data$IAL
-            if(length(dataS4@IAL)) {
-              if(is.matrix(dataS4@IAL)) {
+            if (!is.null(data$s_CAL)) dataS4@IAL <- data$s_CAL
+            if (!is.null(data$IAL)) dataS4@IAL <- data$IAL
+            if (length(dataS4@IAL)) {
+              if (is.matrix(dataS4@IAL)) {
                 dataS4@IAL_ESS <- apply(dataS4@IAL, 1, sum, na.rm = TRUE) %>% pmin(ESS[2])
               } else {
                 dataS4@IAL_ESS <- apply(dataS4@IAL, c(1, 3), sum, na.rm = TRUE) %>% pmin(ESS[2])
               }
             }
             
-            if(!is.null(data$C_eq)) dataS4@C_eq <- data$C_eq
-            if(!is.null(data$C_eq_sd)) dataS4@C_eq_sd <- data$C_eq_sd
-            if(!is.null(data$E_eq)) dataS4@E_eq <- data$E_eq
+            if (!is.null(data$C_eq)) dataS4@C_eq <- data$C_eq
+            if (!is.null(data$C_eq_sd)) dataS4@C_eq_sd <- data$C_eq_sd
+            if (!is.null(data$E_eq)) dataS4@E_eq <- data$E_eq
             
-            if(!is.null(data$abs_I)) dataS4@abs_I <- data$abs_I
-            if(!is.null(data$I_units)) dataS4@I_units <- data$I_units
+            if (!is.null(data$abs_I)) dataS4@abs_I <- data$abs_I
+            if (!is.null(data$I_units)) dataS4@I_units <- data$I_units
             
-            if(!is.null(data$age_error)) dataS4@age_error <- data$age_error
-            if(!is.null(data$sel_block)) dataS4@sel_block <- data$sel_block
+            if (!is.null(data$age_error)) dataS4@age_error <- data$age_error
+            if (!is.null(data$sel_block)) dataS4@sel_block <- data$sel_block
             
             RCM_int(OM = OM, RCMdata = dataS4, condition = condition, selectivity = selectivity, s_selectivity = s_selectivity, LWT = LWT,
                     comp_like = comp_like, prior = prior, max_F = max_F, cores = cores, integrate = integrate, mean_fit = mean_fit,
-                    drop_nonconv = drop_nonconv, drop_highF = drop_highF, control = control, ...)
+                    drop_nonconv = drop_nonconv, drop_highF = drop_highF, control = control, start = start, map = map, ...)
           })
 
 
@@ -328,11 +341,12 @@ setMethod("RCM", signature(OM = "OM", data = "Data"),
           function(OM, data, condition = c("catch", "catch2", "effort"), selectivity = "logistic", s_selectivity = NULL, LWT = list(),
                    comp_like = c("multinomial", "lognormal", "mvlogistic", "dirmult1", "dirmult2"), ESS = c(30, 30), prior = list(),
                    max_F = 3, cores = 1L, integrate = FALSE, mean_fit = FALSE, drop_nonconv = FALSE,
-                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05), ...) {
+                   drop_highF = FALSE, control = list(iter.max = 2e+05, eval.max = 4e+05), 
+                   start = list(), map = list(), ...) {
 
             condition <- match.arg(condition)
             extra_args <- list(...)
-            if(length(ESS) == 1) ESS <- rep(ESS, 2)
+            if (length(ESS) == 1) ESS <- rep(ESS, 2)
 
             ####### Catch and ML from Data object
             vec_slot <- c("Cat", "ML", "CV_Cat")
@@ -346,29 +360,29 @@ setMethod("RCM", signature(OM = "OM", data = "Data"),
             dataS4 <- new("RCMdata")
 
             # Catch or effort
-            if(condition == "effort") {
-              if(all(is.na(data@Effort))) {
+            if (condition == "effort") {
+              if (all(is.na(data@Effort))) {
                 stop("Conditioning on effort but no effort series found", call. = FALSE)
               } else {
                 dataS4@Ehist <- data@Effort[1, ]
-                if(nrow(data@Effort) == OM@nsim) { # Add sketched effort matrix to OM
+                if (nrow(data@Effort) == OM@nsim) { # Add sketched effort matrix to OM
                   OM@cpars$Find <- data@Effort
                   extra_args$OMeff <- TRUE
                 }
               }
-            } else if(is.null(data_vec$Cat)) {
+            } else if (is.null(data_vec$Cat)) {
               stop("Conditioning on catch but no catch data found", call. = FALSE)
             }
-            if(!is.null(data_vec$Cat)) dataS4@Chist <- data_vec$Cat
-            if(!is.null(data_vec$CV_Cat)) dataS4@C_sd <- sdconv(1, data_vec$CV_Cat) 
+            if (!is.null(data_vec$Cat)) dataS4@Chist <- data_vec$Cat
+            if (!is.null(data_vec$CV_Cat)) dataS4@C_sd <- sdconv(1, data_vec$CV_Cat) 
 
             # Index
             Ind <- pull_Index(data, OM@maxage)
-            if(!is.null(Ind$Index)) {
+            if (!is.null(Ind$Index)) {
               dataS4@Index <- Ind$Index
               dataS4@I_sd <- Ind$I_sd
 
-              if(any(!is.na(Ind$V))) {
+              if (any(!is.na(Ind$V))) {
                 extra_args$ivul_par <- Ind$V
                 extra_args$map_ivul_par <- array(NA, dim = dim(Ind$V))
               }
@@ -376,49 +390,52 @@ setMethod("RCM", signature(OM = "OM", data = "Data"),
             }
 
             # Length/age comps
-            if(!is.null(data_matrix$CAA)) {
+            if (!is.null(data_matrix$CAA)) {
               dataS4@CAA <- data_matrix$CAA
               dataS4@CAA_ESS <- apply(dataS4@CAA, 1, sum, na.rm = TRUE) %>% pmin(ESS[1])
             }
-            if(!is.null(data_matrix$CAL)) {
+            if (!is.null(data_matrix$CAL)) {
               dataS4@CAL <- data_matrix$CAL
               dataS4@CAL_ESS <- apply(dataS4@CAL, 1, sum, na.rm = TRUE) %>% pmin(ESS[2])
             }
-            if(!is.null(data_matrix$CAL)) {
-              if(all(is.na(data@CAL_mids))) {
+            if (!is.null(data_matrix$CAL)) {
+              if (all(is.na(data@CAL_mids))) {
                 stop("No length bins found in Data@CAL_mids.", call. = FALSE)
               } else dataS4@length_bin <- data@CAL_mids
             }
 
             # Mean length
-            if(!is.null(data_vec$ML)) dataS4@MS <- data_vec$ML # By default, MS_type = "length" and CV = 0.2
+            if (!is.null(data_vec$ML)) dataS4@MS <- data_vec$ML # By default, MS_type = "length" and CV = 0.2
 
             # Equilibrium catches and/or effort - nothing happens if NULL
-            if(!is.null(extra_args$C_eq)) dataS4@C_eq <- extra_args$C_eq
-            if(!is.null(extra_args$E_eq)) dataS4@E_eq <- extra_args$E_eq
+            if (!is.null(extra_args$C_eq)) dataS4@C_eq <- extra_args$C_eq
+            if (!is.null(extra_args$E_eq)) dataS4@E_eq <- extra_args$E_eq
+            
+            if (!is.null(extra_args$ivul_par)) start$ivul_par <- extra_args$ivul_par
+            if (!is.null(extra_args$map_ivul_par)) map$ivul_par <- extra_args$map_ivul_par
 
             ####### Run RCM
             output <- RCM_int(OM = OM, RCMdata = dataS4, condition = condition, selectivity = selectivity, s_selectivity = Ind$s_sel, LWT = LWT,
                               comp_like = comp_like, prior = prior, max_F = max_F, cores = cores, integrate = integrate, mean_fit = mean_fit,
                               drop_nonconv = drop_nonconv, drop_highF = drop_highF, control = control,
-                              OMeff = extra_args$OMeff, ivul_par = extra_args$ivul_par, map_ivul_par = extra_args$map_ivul_par, ...)
+                              map = map, start = start, OMeff = extra_args$OMeff, ...)
             
             ####### Re-assign index slots from AddInd to their original places
-            if(any(Ind$slotname != "AddInd")) {
+            if (any(Ind$slotname != "AddInd")) {
               Data_out <- output@OM@cpars$Data
               for(i in 1:length(Ind$slotname)) {
-                if(Ind$slotname[i] != "AddInd") {
+                if (Ind$slotname[i] != "AddInd") {
                   slot(Data_out, Ind$slotname[i]) <- Data_out@AddInd[, i, ]
                   slot(Data_out, paste0("CV_", Ind$slotname[i])) <- Data_out@CV_AddInd[, i, ]
                   
-                  if(Ind$slotname[i] == "Ind") output@OM@cpars$I_beta <- rep(1, output@OM@nsim)
-                  if(Ind$slotname[i] == "VInd") output@OM@cpars$VI_beta <- rep(1, output@OM@nsim)
-                  if(Ind$slotname[i] == "SpInd") output@OM@cpars$SpI_beta <- rep(1, output@OM@nsim)
+                  if (Ind$slotname[i] == "Ind") output@OM@cpars$I_beta <- rep(1, output@OM@nsim)
+                  if (Ind$slotname[i] == "VInd") output@OM@cpars$VI_beta <- rep(1, output@OM@nsim)
+                  if (Ind$slotname[i] == "SpInd") output@OM@cpars$SpI_beta <- rep(1, output@OM@nsim)
                 }
               }
 
               ind <- Ind$slotname == "AddInd"
-              if(all(!ind)) {
+              if (all(!ind)) {
                 Data_out@AddInd <- Data_out@CV_AddInd <- Data_out@AddIndV <- array(NA, c(1, 1, 1))
                 Data_out@AddIndType <- NA
                 
