@@ -24,16 +24,16 @@ compare_models <- function(..., label = NULL, color = NULL) {
 
   dots <- list(...)
   class_dots <- vapply(dots, inherits, logical(1), what = "Assessment")
-  if(!all(class_dots)) stop("Some objects provided were not of class Assessment", call. = FALSE)
+  if (!all(class_dots)) stop("Some objects provided were not of class Assessment", call. = FALSE)
 
   n_assess <- length(dots)
-  if(n_assess <= 1) stop("Need more than one assessment model for this function.", call. = FALSE)
+  if (n_assess <= 1) stop("Need more than one assessment model for this function.", call. = FALSE)
 
-  if(is.null(label) || length(label) != n_assess) {
+  if (is.null(label) || length(label) != n_assess) {
     label <- vapply(dots, slot, character(1), name = "Model")
-    if(length(unique(label)) != length(dots)) label <- as.character(substitute(list(...)))[-1]
+    if (length(unique(label)) != length(dots)) label <- as.character(substitute(list(...)))[-1]
   }
-  if(is.null(color) || length(color) != n_assess) {
+  if (is.null(color) || length(color) != n_assess) {
     color <- rich.colors(n_assess)
   }
 
@@ -41,7 +41,7 @@ compare_models <- function(..., label = NULL, color = NULL) {
 
   # F
   slot_F <- function(x) {
-    if(length(x@FMort) == 0) {
+    if (length(x@FMort) == 0) {
       x@U
     } else {
       x@FMort
@@ -52,7 +52,7 @@ compare_models <- function(..., label = NULL, color = NULL) {
 
   # F/FMSY
   slot_FMSY <- function(x) {
-    if(length(x@F_FMSY) == 0) {
+    if (length(x@F_FMSY) == 0) {
       x@U_UMSY
     } else {
       x@F_FMSY
@@ -76,7 +76,7 @@ compare_models <- function(..., label = NULL, color = NULL) {
   # R
   RR <- lapply(dots, slot, name = "R")
   R <- match_R_years(RR)
-  if(!all(is.na(R))) ts_matplot(R, "Recruitment", color = color)
+  if (!all(is.na(R))) ts_matplot(R, "Recruitment", color = color)
 
   par(fig = c(0, 1, 0, 1), oma = c(0, 0, 0, 0), mar = c(0, 0, 0, 0), new = TRUE)
   plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
@@ -92,19 +92,19 @@ ts_matplot <- function(m, ylab, color, dotted_one = FALSE) {
   plot(NULL, NULL, xlim = range(as.numeric(rownames(m))), ylim = c(0, 1.1 * max(m, na.rm = TRUE)), xlab = "Year", ylab = ylab)
   abline(h = 0, col = "grey")
   matlines(x, m, type = "l", col = color, lty = 1, lwd = 2)
-  if(dotted_one) abline(h = 1, lty = 3)
+  if (dotted_one) abline(h = 1, lty = 3)
 }
 
 match_R_years <- function(RR) {
-  yrs <- do.call(c, lapply(RR, function(x) if(length(x) > 0) as.numeric(names(x)) else NA))
-  if(all(is.na(yrs))) return(NA)
+  yrs <- do.call(c, lapply(RR, function(x) if (length(x) > 0) as.numeric(names(x)) else NA))
+  if (all(is.na(yrs))) return(NA)
 
   yrs <- range(yrs, na.rm = TRUE)
 
   R <- matrix(NA, nrow = length(RR), ncol = diff(yrs) + 1)
   R_yrs <- seq(min(yrs), max(yrs))
   for(i in 1:length(RR)) {
-    if(!all(is.na(RR[[i]]))) {
+    if (!all(is.na(RR[[i]]))) {
       ind <- match(as.numeric(names(RR[[i]])), R_yrs)
       R[i, ind] <- RR[[i]]
     }
@@ -123,17 +123,19 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
   filename_html <- paste0(filename, ".html")
   filename_rmd <- paste0(filename, ".Rmd")
 
-  if(!dir.exists(dir)) {
+  if (!dir.exists(dir)) {
     message("Creating directory: \n", dir)
     dir.create(dir)
   }
   message("Writing markdown file: ", file.path(dir, filename_rmd))
 
-  if(Assessment@Model == "SCA2") Assessment@info$data$SR_type <- Assessment@info$SR
-  f <- get(paste0("rmd_", Assessment@Model))
-  rmd_model <- f(Assessment, ...)
+  if (Assessment@Model == "SCA2") Assessment@info$data$SR_type <- Assessment@info$SR
+  dots <- list(...)
+  dots[["Assessment"]] <- Assessment
+  func <- paste0("rmd_", Assessment@Model)
+  rmd_model <- do.call2(func, dots)
 
-  if(!is.null(retro)) {
+  if (!is.null(retro)) {
     rmd_ret <- rmd_retrospective()
   } else rmd_ret <- ""
 
@@ -143,9 +145,9 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
   # Render markdown file
   assign_Assessment_slots(Assessment)
 
-  if(is.null(render_args$input)) render_args$input <- file.path(dir, filename_rmd)
-  if(is.null(render_args$output_format)) render_args$output_format <- "html_document"
-  if(is.null(render_args$output_options) && render_args$output_format == "html_document") {
+  if (is.null(render_args$input)) render_args$input <- file.path(dir, filename_rmd)
+  if (is.null(render_args$output_format)) render_args$output_format <- "html_document"
+  if (is.null(render_args$output_options) && render_args$output_format == "html_document") {
     render_args$output_options <- list(df_print = "paged")
   }
   render_args$quiet <- quiet
@@ -154,7 +156,7 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
   output_filename <- do.call(rmarkdown::render, render_args)
   message("Rendered file: ", output_filename)
 
-  if(open_file) browseURL(output_filename)
+  if (open_file) browseURL(output_filename)
   invisible(output_filename)
 }
 
@@ -192,9 +194,9 @@ report <- function(Assessment, retro = NULL, filename = paste0("report_", Assess
 plot_lognormalvar <- function(m, sd, label = NULL, logtransform = FALSE, color = "black") {
   # plots life history parameters: Linf, K, t0, M, FMSY_M
   ncurve <- length(m)
-  if(!logtransform) {
+  if (!logtransform) {
     true.m <- m
-    if(all(m < 0)) m <- -1 * m # special case needed when t0 < 0
+    if (all(m < 0)) m <- -1 * m # special case needed when t0 < 0
     mu <- mconv(m, sd)
     sdlog <- sdconv(m, sd)
     support <- seq(0.001, max(m + 5*sdlog), length.out = 1e3)
@@ -211,22 +213,22 @@ plot_lognormalvar <- function(m, sd, label = NULL, logtransform = FALSE, color =
     support <- support[ind.tails]
     dist <- as.matrix(dist[ind.tails, ])
 
-    if(all(true.m < 0)) {
+    if (all(true.m < 0)) {
       support <- -1 * support
       xlim_truncated <- range(pretty(support))
       plot(support, dist[, 1], typ = 'l', xlab = label,
            ylab = 'Probability density function', xlim = xlim_truncated,
            ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-      if(ncurve > 1) {
+      if (ncurve > 1) {
         for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
       }
     }
-    if(all(true.m > 0)) {
+    if (all(true.m > 0)) {
       xlim_truncated <- range(pretty(support))
       plot(support, dist[, 1], typ = 'l', xlab = label,
            ylab = 'Probability density function', xlim = xlim_truncated,
            ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-      if(ncurve > 1) {
+      if (ncurve > 1) {
         for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
       }
     }
@@ -234,7 +236,7 @@ plot_lognormalvar <- function(m, sd, label = NULL, logtransform = FALSE, color =
     abline(v = true.m, lty = 2, col = color)
   }
 
-  if(logtransform) {
+  if (logtransform) {
     #f_y(y) = f_x(g-1(y)) * abs(d/dy[g-1(y)])
     #where f is the pdf of distribution, g(y) = exp(X) is the transformation
     #y is the lognormal variable, x is a normal variable
@@ -259,7 +261,7 @@ plot_lognormalvar <- function(m, sd, label = NULL, logtransform = FALSE, color =
     plot(support, dist[, 1], typ = 'l', xlab = label, xlim = xlim_truncated,
          ylab = 'Probability density function',
          ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-    if(ncurve > 1) {
+    if (ncurve > 1) {
       for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
     }
     abline(h = 0, col = 'grey')
@@ -288,7 +290,7 @@ plot_normalvar <- function(m, sd, label = NULL, color = "black") {
   xlim_truncated <- range(pretty(support))
   plot(support, dist[, 1], typ = 'l', xlab = label, ylab = 'Probability density function',
        xlim = xlim_truncated, ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-  if(ncurve > 1) {
+  if (ncurve > 1) {
     for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
   }
   abline(h = 0, col = 'grey')
@@ -327,12 +329,12 @@ plot_betavar <- function(m, sd, label = NULL, is_logit = FALSE, color = "black")
   support <- seq(0.01, 0.99, length.out = 1e3)
   ncurve <- length(m)
   dist <- matrix(NA, nrow = length(support), ncol = ncurve)
-  if(!is_logit) {
+  if (!is_logit) {
     a <- alphaconv(m, sd)
     b <- betaconv(m, sd)
     for(i in 1:ncurve) dist[, i] <- dbeta(support, a[i], b[i])
   }
-  if(is_logit) {
+  if (is_logit) {
     for(i in 1:ncurve) {
       #f_y(y) = f_x(g-1(y)) * abs(d/dy[g-1(y)])
       #where f is the pdf of distribution, g(y) = 1/(1 + exp(-X)) is the transformation
@@ -354,7 +356,7 @@ plot_betavar <- function(m, sd, label = NULL, is_logit = FALSE, color = "black")
 
   plot(support, dist[, 1], typ = 'l', xlab = label, ylab = 'Probability density function',
        xlim = xlim_truncated, ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-  if(ncurve > 1) {
+  if (ncurve > 1) {
     for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
   }
   abline(h = 0, col = 'grey')
@@ -391,10 +393,10 @@ plot_steepness <- function(m, sd, is_transform = FALSE, SR = c("BH", "Ricker"),
   SR <- match.arg(SR)
   ncurve <- length(m)
 
-  if(SR == "BH") {
+  if (SR == "BH") {
     support <- seq(0.201, 0.999, 0.001)
     dist <- matrix(NA, nrow = length(support), ncol = ncurve)
-    if(is_transform) {
+    if (is_transform) {
       #f_y(y) = f_x(g-1(y)) * abs(d/dy[g-1(y)])
       #where f is the pdf of distribution, g(y) = 0.2 + 0.8/(1 + exp(-X)) is the transformation
       #y is steepness, x is a normal variable
@@ -412,7 +414,7 @@ plot_steepness <- function(m, sd, is_transform = FALSE, SR = c("BH", "Ricker"),
       b <- betaconv(m = m.transformed, sd = sd/0.8)
 
       for(i in 1:ncurve) {
-        if(a[i] > 0 && b[i] > 0) dist[, i] <- dbeta((support - 0.2)/0.8, a[i], b[i]) / 0.8
+        if (a[i] > 0 && b[i] > 0) dist[, i] <- dbeta((support - 0.2)/0.8, a[i], b[i]) / 0.8
         else {
           dist[, i] <- dnorm(support, m[i], sd[i])
           #warning("Transformation not possible with value of m and sd for steepness. Typically, sd is too high given the value of m, resulting in negative beta distribution parameters).")
@@ -421,8 +423,8 @@ plot_steepness <- function(m, sd, is_transform = FALSE, SR = c("BH", "Ricker"),
     }
   }
 
-  if(SR == "Ricker") {
-    if(is_transform) {
+  if (SR == "Ricker") {
+    if (is_transform) {
       #f_y(y) = f_x(g-1(y)) * abs(d/dy[g-1(y)])
       #where f is the pdf of distribution, g(y) = 0.2 + 0.8/(1 + exp(-X)) is the transformation
       #y is steepness, x is a normal variable
@@ -469,7 +471,7 @@ plot_steepness <- function(m, sd, is_transform = FALSE, SR = c("BH", "Ricker"),
   plot(support, dist[, 1], typ = 'l', xlab = 'Steepness (h)',
        ylab = 'Probability density function', xlim = range(pretty(support)),
        ylim = c(0, 1.1 * max(dist, na.rm = TRUE)), col = color[1])
-  if(ncurve > 1) {
+  if (ncurve > 1) {
     for(i in 2:ncurve) lines(support, dist[, i], col = color[i])
   }
   abline(h = 0, col = 'grey')
@@ -511,9 +513,9 @@ plot_timeseries <- function(Year, obs, fit = NULL, obs_CV = NULL, obs_CV_CI = 0.
                             fit_color = "red", label = "Observed data") {
 
   # Without CV interval
-  if(is.null(obs_CV)) {
+  if (is.null(obs_CV)) {
     y.max <- max(c(obs, fit), na.rm = TRUE)
-    if(is.null(obs_ind_blue)) {
+    if (is.null(obs_ind_blue)) {
       plot(Year, obs, typ = 'o', ylab = label, ylim = c(0, 1.1 * y.max))
     } else {
       plot(Year, obs, typ = 'n', ylab = label, ylim = c(0, 1.1 * y.max))
@@ -523,15 +525,15 @@ plot_timeseries <- function(Year, obs, fit = NULL, obs_CV = NULL, obs_CV_CI = 0.
   }
 
   # With CV interval
-  if(!is.null(obs_CV) || (!is.null(obs_upper) & !is.null(obs_lower))) {
+  if (!is.null(obs_CV) || (!is.null(obs_upper) & !is.null(obs_lower))) {
     sigma <- sdconv(1, obs_CV)
-    if(is.null(obs_upper))
+    if (is.null(obs_upper))
       obs_upper <- exp(log(obs) + qnorm(1-0.5*(1-obs_CV_CI)) * sigma)
-    if(is.null(obs_lower))
+    if (is.null(obs_lower))
       obs_lower <- exp(log(obs) + qnorm(0.5*(1-obs_CV_CI)) * sigma)
     y.max <- max(c(obs_lower, obs_upper, obs, fit), na.rm = TRUE)
 
-    if(is.null(obs_ind_blue)) {
+    if (is.null(obs_ind_blue)) {
       plot(Year, obs, typ = 'o', ylab = label, ylim = c(0, 1.1 * y.max))
       arrows(Year, obs_lower, Year, obs_upper, length = 0.025, angle = 90, code = 3)
     } else {
@@ -545,7 +547,7 @@ plot_timeseries <- function(Year, obs, fit = NULL, obs_CV = NULL, obs_CV_CI = 0.
              obs_upper[obs_ind_blue], length = 0.025, angle = 90, code = 3, col = "blue")
     }
   }
-  if(!is.null(fit)) lines(Year, fit, lwd = fit_linewidth, col = fit_color)
+  if (!is.null(fit)) lines(Year, fit, lwd = fit_linewidth, col = fit_color)
   abline(h = 0, col = 'grey')
 
   invisible()
@@ -573,10 +575,10 @@ plot_residuals <- function(Year, res, res_sd = NULL, res_sd_CI = 0.95,
                            res_upper = NULL, res_lower = NULL, res_ind_blue = NULL, draw_zero = TRUE,
                            zero_linetype = 2, label = "Residual") {
   # Without sd interval
-  if(is.null(res_sd)) {
+  if (is.null(res_sd)) {
     res.lim <- max(abs(res), na.rm = TRUE)
-    if(!res.lim || is.infinite(res.lim)) res.lim <- 1
-    if(is.null(res_ind_blue) || all(!res_ind_blue)) {
+    if (!res.lim || is.infinite(res.lim)) res.lim <- 1
+    if (is.null(res_ind_blue) || all(!res_ind_blue)) {
       plot(Year, res, typ = 'o', ylab = label, ylim = c(-res.lim, res.lim))
     } else {
       plot(Year, res, typ = 'n', ylab = label, ylim = c(-res.lim, res.lim))
@@ -586,12 +588,12 @@ plot_residuals <- function(Year, res, res_sd = NULL, res_sd_CI = 0.95,
   }
 
   # With CV interval
-  if(!is.null(res_sd) || (!is.null(res_upper) & !is.null(res_lower))) {
-    if(is.null(res_upper)) res_upper <- res + qnorm(1-0.5*(1-res_sd_CI)) * res_sd
-    if(is.null(res_lower)) res_lower <- res + qnorm(0.5*(1-res_sd_CI)) * res_sd
+  if (!is.null(res_sd) || (!is.null(res_upper) & !is.null(res_lower))) {
+    if (is.null(res_upper)) res_upper <- res + qnorm(1-0.5*(1-res_sd_CI)) * res_sd
+    if (is.null(res_lower)) res_lower <- res + qnorm(0.5*(1-res_sd_CI)) * res_sd
     res.lim <- max(abs(c(res_lower, res_upper, res)), na.rm = TRUE)
 
-    if(is.null(res_ind_blue) || all(!res_ind_blue)) {
+    if (is.null(res_ind_blue) || all(!res_ind_blue)) {
       plot(Year, res, typ = 'o', ylab = label, ylim = c(-res.lim, res.lim))
       arrows(Year, res_lower, Year, res_upper, length = 0.025, angle = 90,
              code = 3, col = 'grey30')
@@ -606,7 +608,7 @@ plot_residuals <- function(Year, res, res_sd = NULL, res_sd_CI = 0.95,
              res_upper[res_ind_blue], length = 0.025, angle = 90, code = 3, col = 'blue')
     }
   }
-  if(draw_zero) abline(h = 0, lty = zero_linetype)
+  if (draw_zero) abline(h = 0, lty = zero_linetype)
   invisible()
 }
 
@@ -652,28 +654,28 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
                              bubble_adj = 5, bubble_color = c("black", "white"), fit_linewidth = 3, fit_color = "red") {
   plot_type <- match.arg(plot_type)
   annual_yscale <- match.arg(annual_yscale)
-  if(is.null(CAL_bins)) data_type <- "age" else data_type <- "length"
+  if (is.null(CAL_bins)) data_type <- "age" else data_type <- "length"
 
-  if(!is.null(fit) && !all(dim(fit) == dim(obs))) stop("Dimensions of 'obs' and 'fit' do not match.")
+  if (!is.null(fit) && !all(dim(fit) == dim(obs))) stop("Dimensions of 'obs' and 'fit' do not match.")
 
-  if(data_type == 'length') {
+  if (data_type == 'length') {
     data_val <- CAL_bins
     data_lab <- "Length"
   }
-  if(data_type == 'age') {
-    data_val <- if(is.null(ages)) 1:ncol(obs) else ages
+  if (data_type == 'age') {
+    data_val <- if (is.null(ages)) 1:ncol(obs) else ages
     data_lab <- "Age"
   }
-  if(!is.null(N)) N <- round(N, 1)
+  if (!is.null(N)) N <- round(N, 1)
 
-  if(annual_yscale == "proportions") {
+  if (annual_yscale == "proportions") {
     obs_prob_all <- obs/rowSums(obs, na.rm = TRUE)
-    if(!is.null(fit)) fit_prob_all <- fit/rowSums(fit, na.rm = TRUE)
+    if (!is.null(fit)) fit_prob_all <- fit/rowSums(fit, na.rm = TRUE)
     else fit_prob_all <- NULL
   }
-  if(annual_yscale == "raw") {
+  if (annual_yscale == "raw") {
     obs_prob_all <- obs
-    if(!is.null(fit)) fit_prob_all <- fit
+    if (!is.null(fit)) fit_prob_all <- fit
     else fit_prob_all <- NULL
   }
 
@@ -681,15 +683,15 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
   #ind <- rowSums(obs, na.rm = TRUE) > 0
   Year <- Year[ind]
   obs <- obs[ind, , drop = FALSE]
-  if(!is.null(fit)) fit <- fit[ind, , drop = FALSE]
-  if(!is.null(N)) N <- N[ind]
+  if (!is.null(fit)) fit <- fit[ind, , drop = FALSE]
+  if (!is.null(N)) N <- N[ind]
 
   # Bubble plot (obs)
-  if('bubble_data' %in% plot_type) {
+  if ('bubble_data' %in% plot_type) {
     range_obs <- pretty(obs, n = 6)
     n1 <- range_obs[2]
     n2 <- pretty(quantile(obs[obs > 0], na.rm = TRUE, probs = 0.9))[2]
-    if(n2 < n1) n1 <- 0.5 * n2
+    if (n2 < n1) n1 <- 0.5 * n2
     diameter_max <- bubble_adj / n2
     plot(NULL, NULL, typ = 'n', xlim = range(Year), xlab = "Year",
          ylim = range(data_val), ylab = data_lab)
@@ -703,8 +705,8 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
     return(invisible())
   }
   # Bubble plot (residuals if applicable)
-  if('bubble_residuals' %in% plot_type) {
-    if(is.null(fit)) stop("No fitted data available.")
+  if ('bubble_residuals' %in% plot_type) {
+    if (is.null(fit)) stop("No fitted data available.")
 
     obs_prob <- obs/rowSums(obs, na.rm = TRUE)
     fit_prob <- fit/rowSums(fit, na.rm = TRUE)
@@ -725,38 +727,38 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
     return(invisible())
   }
   # Mean length or age over time
-  if('mean' %in% plot_type) {
+  if ('mean' %in% plot_type) {
     mu <- mupred <- numeric(length = length(Year))
     for(i in 1:length(mu)) {
       mu[i] <- weighted.mean(data_val, obs[i, ], na.rm = TRUE)
-      if(!is.null(fit)) mupred[i] <- weighted.mean(data_val, fit[i, ], na.rm = TRUE)
+      if (!is.null(fit)) mupred[i] <- weighted.mean(data_val, fit[i, ], na.rm = TRUE)
     }
     ind2 <- (which(!is.na(mu) & mu > 0)[1]):length(mu)
     plot(Year[ind2], mu[ind2], xlab = "Year", ylab = paste0("Mean ", data_type), typ = "o")
-    if(!is.null(fit)) lines(Year[ind2], mupred[ind2], lwd = fit_linewidth, col = fit_color)
+    if (!is.null(fit)) lines(Year[ind2], mupred[ind2], lwd = fit_linewidth, col = fit_color)
 
     return(invisible())
   }
 
   # Annual comps (obs vs. fitted if available)
-  if("annual" %in% plot_type) {
+  if ("annual" %in% plot_type) {
     old_par <- par(no.readonly = TRUE)
     on.exit(par(old_par))
     par(mfcol = c(4, 4), mar = rep(0, 4), oma = c(5.1, 5.1, 2.1, 2.1))
     ylim <- c(0, 1.1 * max(obs_prob_all, fit_prob_all, na.rm = TRUE))
 
-    if(annual_yscale == "proportions") {
+    if (annual_yscale == "proportions") {
       obs_prob <- obs/rowSums(obs, na.rm = TRUE)
-      if(!is.null(fit)) fit_prob <- fit/rowSums(fit, na.rm = TRUE)
+      if (!is.null(fit)) fit_prob <- fit/rowSums(fit, na.rm = TRUE)
       else fit_prob <- NULL
     }
-    if(annual_yscale == "raw") {
+    if (annual_yscale == "raw") {
       obs_prob <- obs
       fit_prob <- fit
     }
 
     yaxp <- c(0, max(pretty(ylim, n = 4)), 4)
-    if(max(obs_prob_all, fit_prob_all, na.rm = TRUE) == 1) yaxp <- c(0, 1, 4)
+    if (max(obs_prob_all, fit_prob_all, na.rm = TRUE) == 1) yaxp <- c(0, 1, 4)
 
     las <- 1
     for(i in 1:length(Year)) {
@@ -766,10 +768,10 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
       plot(data_val, obs_prob[i, ], typ = "n", ylim = ylim, yaxp = yaxp, xaxt = xaxt, yaxt = yaxt, las = las)
       abline(h = 0, col = "grey")
       lines(data_val, obs_prob[i, ], typ = "o")
-      if(!is.null(fit)) lines(data_val, fit_prob[i, ], lwd = fit_linewidth, col = fit_color)
+      if (!is.null(fit)) lines(data_val, fit_prob[i, ], lwd = fit_linewidth, col = fit_color)
       legend("topright", legend = c(Year[i], ifelse(is.null(N), "", paste0("N = ", N[i]))), bty = "n", xjust = 1)
 
-      if(i %% 16 == 1) {
+      if (i %% 16 == 1) {
         mtext(data_lab, side = 1, line = 3, outer = TRUE)
         mtext(annual_ylab, side = 2, line = 3.5, outer = TRUE)
       }
@@ -783,11 +785,11 @@ plot_composition <- function(Year = 1:nrow(obs), obs, fit = NULL, plot_type = c(
 
 
 plot_surplus_production <- function(B, B0 = NULL, C, yield_fn = NULL, arrow_size = 0.07, xlab = NULL) {
-  if(!is.null(B0)) {
+  if (!is.null(B0)) {
     B <- B/B0
-    if(is.null(xlab)) xlab <- expression(B/B[0])
+    if (is.null(xlab)) xlab <- expression(B/B[0])
   } else {
-    if(is.null(xlab)) xlab <- "Biomass"
+    if (is.null(xlab)) xlab <- "Biomass"
   }
   B_now <- B[1:(length(B)-1)]
   B_next <- B[2:length(B)]
@@ -797,8 +799,8 @@ plot_surplus_production <- function(B, B0 = NULL, C, yield_fn = NULL, arrow_size
   ylim <- c(min(0, min(SP_now)), max(SP_now))
   plot(B_now, SP_now, typ = "n", xlab = xlab, xlim = xlim, ylim = ylim,
        ylab = "Surplus production")
-  if(!is.null(yield_fn)) {
-    if(!is.null(B0)) lines(yield_fn$B_B0, yield_fn$Yield) else {
+  if (!is.null(yield_fn)) {
+    if (!is.null(B0)) lines(yield_fn$B_B0, yield_fn$Yield) else {
       lines(yield_fn$B, yield_fn$Yield)
     }
   }
@@ -812,12 +814,12 @@ plot_surplus_production <- function(B, B0 = NULL, C, yield_fn = NULL, arrow_size
 
 plot_Kobe <- function(biomass, exploit, arrow_size = 0.07, color = TRUE, xlab = expression(B/B[MSY]), ylab = expression(F/F[MSY])) {
   n.arrows <- length(exploit)
-  if(length(biomass) > n.arrows) biomass <- biomass[1:n.arrows]
+  if (length(biomass) > n.arrows) biomass <- biomass[1:n.arrows]
 
   x.max <- max(biomass, 1)
   y.max <- max(exploit, 1)
   plot(NULL, NULL, typ = "n", xlab = xlab, ylab = ylab, xlim = c(0, max(1.1, 1.1 * x.max)), ylim = c(0, max(1.1, 1.1 * y.max)))
-  if(color) {
+  if (color) {
     # Colors from https://www.rapidtables.com/web/color/html-color-codes.html
     green <- "#228B22"    #forestgreen
     yellow <- "#F0E68C"   #khaki
@@ -834,7 +836,7 @@ plot_Kobe <- function(biomass, exploit, arrow_size = 0.07, color = TRUE, xlab =
          x1 = biomass[2:n.arrows], y1 = exploit[2:n.arrows], length = arrow_size)
   abline(h = 0, col = "grey")
   abline(v = 0, col = "grey")
-  if(!color) {
+  if (!color) {
     abline(h = 1, lty = 2)
     abline(v = 1, lty = 2)
   }
@@ -863,27 +865,27 @@ plot_Kobe <- function(biomass, exploit, arrow_size = 0.07, color = TRUE, xlab =
 #' @export plot_SR
 plot_SR <- function(Spawners, expectedR, R0 = NULL, S0 = NULL, rec_dev = NULL, trajectory = FALSE,
                     y_zoom = NULL, ylab = "Recruitment") {
-  if(is.null(rec_dev)) {
+  if (is.null(rec_dev)) {
     R.max <- 1.1 * max(expectedR)
   } else {
-    if(is.null(y_zoom)) R.max <- 1.1 * max(rec_dev)
+    if (is.null(y_zoom)) R.max <- 1.1 * max(rec_dev)
     else R.max <- y_zoom * max(expectedR)
   }
   S.max <- 1.1 * max(c(Spawners, S0))
   plot(Spawners[order(Spawners)], expectedR[order(Spawners)], typ = "l", xlim = c(0, 1.05 * S.max), ylim = c(0, 1.1 * R.max),
        xlab = "Spawning Stock Biomass (SSB)", lwd = ifelse(is.null(rec_dev), 1, 3), ylab = ylab)
-  if(trajectory) {
+  if (trajectory) {
     n.arrows <- length(Spawners)
     arrows(x0 = Spawners[1:(n.arrows-1)], y0 = rec_dev[1:(n.arrows-1)],
            x1 = Spawners[2:n.arrows], y1 = rec_dev[2:n.arrows], length = 0.07)
   } else {
-    if(is.null(rec_dev)) {
+    if (is.null(rec_dev)) {
       points(Spawners, expectedR)
     } else {
       points(Spawners, rec_dev)
     }
   }
-  if(!is.null(R0) && !is.null(S0)) points(S0, R0, col = "red", pch = 16)
+  if (!is.null(R0) && !is.null(S0)) points(S0, R0, col = "red", pch = 16)
   abline(h = 0, col = "grey")
   abline(v = 0, col = "grey")
 }
@@ -907,7 +909,7 @@ plot_ogive <- function(Age, ogive, label = "Selectivity") {
 
 calculate_Mohn_rho <- function(ts, est = NULL, ts_lab, est_lab = NULL) {
   rho_ts <- apply(ts, 3, Mohn_rho)
-  rho_est <- if(!is.null(est)) apply(est, 2, Mohn_rho, type = "est") else NULL
+  rho_est <- if (!is.null(est)) apply(est, 2, Mohn_rho, type = "est") else NULL
 
   ans <- matrix(c(rho_ts, rho_est), ncol = 1)
   dimnames(ans) <- list(c(ts_lab, est_lab), "Mohn's rho")
@@ -917,7 +919,7 @@ calculate_Mohn_rho <- function(ts, est = NULL, ts_lab, est_lab = NULL) {
 
 Mohn_rho <- function(x, type = c("ts", "est")) {
   type <- match.arg(type)
-  if(type == "ts") { # let x be a matrix of nrow = n_peel + 1 and ncol = nyear + 1
+  if (type == "ts") { # let x be a matrix of nrow = n_peel + 1 and ncol = nyear + 1
     terminal_ind <- apply(x[-1, , drop = FALSE], 1, function(y) sum(!is.na(y)))
     n_peel <- length(terminal_ind)
     rho <- diag(x[1:n_peel + 1, terminal_ind, drop = FALSE])/x[1, terminal_ind] - 1
